@@ -137,6 +137,10 @@ def _validate_edge(conf: Dict[str, Any]) -> None:
             "Edge and VolumePairList are incompatible, "
             "Edge will override whatever pairs VolumePairlist selects."
         )
+    if not conf.get('ask_strategy', {}).get('use_sell_signal', True):
+        raise OperationalException(
+            "Edge requires `use_sell_signal` to be True, otherwise no sells will happen."
+        )
 
 
 def _validate_whitelist(conf: Dict[str, Any]) -> None:
