@@ -214,10 +214,9 @@ def _download_pair_history(datadir: Path,
         data_handler.ohlcv_store(pair, timeframe, data=data)
         return True
 
-    except Exception as e:
-        logger.error(
-            f'Failed to download history data for pair: "{pair}", timeframe: {timeframe}. '
-            f'Error: {e}'
+    except Exception:
+        logger.exception(
+            f'Failed to download history data for pair: "{pair}", timeframe: {timeframe}.'
         )
         return False
 
@@ -304,10 +303,9 @@ def _download_trades_history(exchange: Exchange,
         logger.info(f"New Amount of trades: {len(trades)}")
         return True
 
-    except Exception as e:
-        logger.error(
+    except Exception:
+        logger.exception(
             f'Failed to download historic trades for pair: "{pair}". '
-            f'Error: {e}'
         )
         return False
 
@@ -356,9 +354,12 @@ def convert_trades_to_ohlcv(pairs: List[str], timeframes: List[str],
             if erase:
                 if data_handler_ohlcv.ohlcv_purge(pair, timeframe):
                     logger.info(f'Deleting existing data for pair {pair}, interval {timeframe}.')
-            ohlcv = trades_to_ohlcv(trades, timeframe)
-            # Store ohlcv
-            data_handler_ohlcv.ohlcv_store(pair, timeframe, data=ohlcv)
+            try:
+                ohlcv = trades_to_ohlcv(trades, timeframe)
+                # Store ohlcv
+                data_handler_ohlcv.ohlcv_store(pair, timeframe, data=ohlcv)
+            except ValueError:
+                logger.exception(f'Could not convert {pair} to OHLCV.')
 
 
 def get_timerange(data: Dict[str, DataFrame]) -> Tuple[arrow.Arrow, arrow.Arrow]:
