@@ -270,7 +270,6 @@ class Trade(_DECL_BASE):
             'amount_requested': round(self.amount_requested, 8) if self.amount_requested else None,
             'stake_amount': round(self.stake_amount, 8),
             'strategy': self.strategy,
-            'ticker_interval': self.timeframe,  # DEPRECATED
             'timeframe': self.timeframe,
 
             'fee_open': self.fee_open,
@@ -295,12 +294,16 @@ class Trade(_DECL_BASE):
                 tzinfo=timezone.utc).timestamp() * 1000) if self.close_date else None,
             'close_rate': self.close_rate,
             'close_rate_requested': self.close_rate_requested,
-            'close_profit': self.close_profit,
-            'close_profit_abs': self.close_profit_abs,
+            'close_profit': self.close_profit,  # Deprecated
+            'close_profit_pct': round(self.close_profit * 100, 2) if self.close_profit else None,
+            'close_profit_abs': self.close_profit_abs,  # Deprecated
+
+            'profit_ratio': self.close_profit,
+            'profit_pct': round(self.close_profit * 100, 2) if self.close_profit else None,
+            'profit_abs': self.close_profit_abs,
 
             'sell_reason': self.sell_reason,
             'sell_order_status': self.sell_order_status,
-            'stop_loss': self.stop_loss,  # Deprecated - should not be used
             'stop_loss_abs': self.stop_loss,
             'stop_loss_ratio': self.stop_loss_pct if self.stop_loss_pct else None,
             'stop_loss_pct': (self.stop_loss_pct * 100) if self.stop_loss_pct else None,
@@ -309,7 +312,6 @@ class Trade(_DECL_BASE):
                                      if self.stoploss_last_update else None),
             'stoploss_last_update_timestamp': int(self.stoploss_last_update.replace(
                 tzinfo=timezone.utc).timestamp() * 1000) if self.stoploss_last_update else None,
-            'initial_stop_loss': self.initial_stop_loss,  # Deprecated - should not be used
             'initial_stop_loss_abs': self.initial_stop_loss,
             'initial_stop_loss_ratio': (self.initial_stop_loss_pct
                                         if self.initial_stop_loss_pct else None),
@@ -395,7 +397,7 @@ class Trade(_DECL_BASE):
             if self.is_open:
                 logger.info(f'{order_type.upper()}_SELL has been fulfilled for {self}.')
             self.close(safe_value_fallback(order, 'average', 'price'))
-        elif order_type in ('stop_loss_limit', 'stop-loss', 'stop'):
+        elif order_type in ('stop_loss_limit', 'stop-loss', 'stop-loss-limit', 'stop'):
             self.stoploss_order_id = None
             self.close_rate_requested = self.stop_loss
             if self.is_open:
