@@ -247,18 +247,17 @@ class Telegram(RPC):
                     "*Open Rate:* `{open_rate:.8f}`",
                     "*Close Rate:* `{close_rate}`" if r['close_rate'] else "",
                     "*Current Rate:* `{current_rate:.8f}`",
-                    ("*Close Profit:* `{close_profit_pct}`"
-                     if r['close_profit_pct'] is not None else ""),
-                    "*Current Profit:* `{current_profit_pct:.2f}%`",
+                    ("*Current Profit:* " if r['is_open'] else "*Close Profit: *")
+                    + "`{profit_pct:.2f}%`",
                 ]
-                if (r['stop_loss'] != r['initial_stop_loss']
+                if (r['stop_loss_abs'] != r['initial_stop_loss_abs']
                         and r['initial_stop_loss_pct'] is not None):
                     # Adding initial stoploss only if it is different from stoploss
-                    lines.append("*Initial Stoploss:* `{initial_stop_loss:.8f}` "
+                    lines.append("*Initial Stoploss:* `{initial_stop_loss_abs:.8f}` "
                                  "`({initial_stop_loss_pct:.2f}%)`")
 
                 # Adding stoploss and stoploss percentage only if it is not None
-                lines.append("*Stoploss:* `{stop_loss:.8f}` " +
+                lines.append("*Stoploss:* `{stop_loss_abs:.8f}` " +
                              ("`({stop_loss_pct:.2f}%)`" if r['stop_loss_pct'] else ""))
                 lines.append("*Stoploss distance:* `{stoploss_current_dist:.8f}` "
                              "`({stoploss_current_dist_pct:.2f}%)`")
@@ -776,7 +775,8 @@ class Telegram(RPC):
         :param update: message update
         :return: None
         """
-        val = self._rpc_show_config(self._freqtrade.config)
+        val = RPC._rpc_show_config(self._freqtrade.config, self._freqtrade.state)
+
         if val['trailing_stop']:
             sl_info = (
                 f"*Initial Stoploss:* `{val['stoploss']}`\n"
